function plot_mocap_points(markers)
% plot_mocap_points(markers)
%
% markers is a 3d array of size (# frames)*(# points)*(# dimensions: 2 or 3)
% or (# dimensions: 2 or 3)*(# points)*(# frames).

% Author: David Ross, 2007

axis_limits = get_limits(markers);

if any(size(markers,3) == [2 3])
    markers = permute(markers,[3 2 1]);
end

two_dimensional = (size(markers,1) == 2);

% create the figure
figure;
axis(axis_limits);
axis equal;
hold on;
set(gcf,'DoubleBuffer','on','MenuBar','None');
whitebg(gcf,'k');

% draw the first frame
if two_dimensional
    obj = plot(markers(1,:,1),markers(2,:,1),'.','MarkerSize', 20);
else
    obj = plot3(markers(1,:,1),markers(2,:,1),markers(3,:,1),'.', ...
        'MarkerSize', 20);
end
drawnow;

% draw subsequent frames
for ff = 2:size(markers,3)
    if two_dimensional
        set(obj, 'XData', markers(1,:,ff), 'YData', markers(2,:,ff));
    else
        set(obj, 'XData', markers(1,:,ff), 'YData', markers(2,:,ff), ...
            'ZData', markers(3,:,ff));
    end
    drawnow;
end

hold off
